@@ -1,6 +1,6 @@
 # Copyright (c) 2003-7 by Barry Rowlingson and Roger Bivand
 
-setClass("CRS", representation(projargs = "character"),
+setClass("CRS", slots = c(projargs = "character"),
     		prototype = list(projargs = character(1)),
                 validity = function(object) {
                   if (length(object@projargs) != 1)
