@@ -1,5 +1,5 @@
 setClass("GridTopology", 
-	representation(cellcentre.offset = "numeric",
+	slots = c(cellcentre.offset = "numeric",
 		cellsize = "numeric",
 		cells.dim = "integer"),
 	prototype = list( # not so relevant what this does
