@@ -1,6 +1,6 @@
 setClass("SpatialPixelsDataFrame",
-	representation("SpatialPixels", data = "data.frame", coords.nrs = "numeric"),
-	contains = "SpatialPointsDataFrame",
+	contains = c("SpatialPixels", "SpatialPointsDataFrame"),
+	slots = c(data = "data.frame", coords.nrs = "numeric"),
 	validity = function(object) {
 		if (length(object@grid.index) != nrow(object@data))
 			stop("grid.index should have length equal to data slot")
@@ -11,7 +11,8 @@ setClass("SpatialPixelsDataFrame",
 )
 
 setClass("SpatialGridDataFrame",
-	representation("SpatialGrid", data = "data.frame"),
+	contains = "SpatialGrid",
+	slots = c(data = "data.frame"),
 	validity = function(object) {
 		if (.NumberOfCells(object@grid) != nrow(object@data))
 			stop("unequal number of objects in full grid and data slot")
