@@ -1,5 +1,5 @@
 setClass("Line", 
-	representation(coords = "matrix"),
+	slots = c(coords = "matrix"),
 	prototype = list(coords = matrix(0)),
 	validity = function(object) {
 		if (any(is.na(object@coords)))
@@ -13,7 +13,7 @@ setClass("Line",
 )
 
 setClass("Lines",
-	representation(Lines = "list", ID = "character"),
+	slots = c(Lines = "list", ID = "character"),
 	validity = function(object) {
 		if (any(sapply(object@Lines, function(x) !is(x, "Line"))))
 			stop("not a list of Line objects")
@@ -21,7 +21,8 @@ setClass("Lines",
 })
 
 setClass("SpatialLines",
-	representation("Spatial", lines = "list"),
+	contains = "Spatial", 
+	slots = c(lines = "list"),
 	prototype = list(bbox = matrix(rep(NA, 2), 2, 2, 
 			dimnames = list(NULL, c("min","max"))),
 		proj4string = CRS(as.character(NA)),
@@ -29,7 +30,8 @@ setClass("SpatialLines",
 	validity = function(object) {
 		if (any(unlist(lapply(object@lines, function(x) 
 			!is(x, "Lines"))))) stop("lines not Lines objects")
-		if (any(duplicated(sapply(slot(object, "lines"), function(i) slot(i, "ID")))))
+                IDs <- sapply(slot(object, "lines"), function(i) slot(i, "ID"))
+		if (anyDuplicated(IDs))
 			return("non-unique Lines ID slot values")
 #		if (length(object@lines) != 
 #			length(unique(sapply(slot(object, "lines"),
@@ -40,24 +42,22 @@ setClass("SpatialLines",
 )
 
 getSLlinesSlot <- function(SL) {
-    .Deprecated("slot", msg="use *apply and slot directly")
+    .Deprecated("slot", msg="use *apply and slot directly", package = "sp")
     SL@lines
 }
 
 getLinesLinesSlot <- function(SL) {
-    .Deprecated("slot", msg="use *apply and slot directly")
+    .Deprecated("slot", msg="use *apply and slot directly", package = "sp")
     SL@Lines
 }
 
 getLinesIDSlot <- function(Lines) {
-    .Deprecated("slot", msg="use *apply and slot directly")
+    .Deprecated("slot", msg="use *apply and slot directly", package = "sp")
     Lines@ID
 }
 
 getSLLinesIDSlots <- function(SL) {
-        .Deprecated("slot", msg="use *apply and slot directly")
+        .Deprecated("slot", msg="use *apply and slot directly", package = "sp")
 	Sls <- slot(SL, "lines")
 	sapply(Sls, function(x) slot(x, "ID"))
 }
-
-
