@@ -76,8 +76,9 @@ void sp_gcdist(double *lon1, double *lon2, double *lat1, double *lat2,
 		double *dist);
 void sp_dists(double *u, double *v, double *uout, double *vout, 
 		int *n, double *dists, int *lonlat);
+void sp_dists_seq(double *u, double *v, int *n, double *dists, int *lonlat);
 void sp_lengths(double *u, double *v, int *n, double *lengths, int *lonlat);
-SEXP sp_zerodist(SEXP pp, SEXP pncol, SEXP zero);
+SEXP sp_zerodist(SEXP pp, SEXP pncol, SEXP zero, SEXP lonlat);
 SEXP pointsInBox(SEXP lb, SEXP px, SEXP py);
 SEXP tList(SEXP nl, SEXP m);
 
@@ -91,7 +92,7 @@ void    SP_PREFIX(FindCG)( int n, tPointd *P, tPointd CG, double *Areasum2 );
 void    SP_PREFIX(Centroid3)( tPointd p1, tPointd p2, tPointd p3, tPointd c );
 void SP_PREFIX(spRFindCG_c)( SEXP n, SEXP coords, double *xc, double *yc, 
 		double *area );
-void SP_PREFIX(comm2comment)(char *buf, int *comm, int nps);
+void SP_PREFIX(comm2comment)(char *buf, int bufsiz, int *comm, int nps);
 
 SEXP SP_PREFIX(Polygon_c)(SEXP coords, SEXP n, SEXP hole);
 SEXP SP_PREFIX(Polygons_c)(SEXP pls, SEXP ID);
